==> ascii_img_stuff-0.1.1.tar.gz: ascii_img_stuff-0.1.1/README.md <==
# about 
ascii .txt image rendering with python  
this is the program i use to make all the ascii drawings you see on my page

## usage
**WORKS IN WSL2 and DEBIAN/UBUNTU \*NIX**
```bash

git clone "https://github.com/hashirkz/ascii_stuff"
cd ascii_stuff
./setup.sh

# installs python program to /usr/bin/ascii
ascii
```

### example
```
sleepyzzz:/mnt/c/users/hashi/documents/ascii_stuff$ ascii
path to img: ./imgs/pfp.jpg
height for .txt file: 40
invert y/n: n
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::.::::::::::::::::::::::::::::
:::::::::::::::::::::::::::::::::::::-:::::::::::::::::::::::::::::::..:::::::::::::::::::::::::::::
::::::::::::::::::::::::::::::::::::--:::..................:.::::::::..::........:::::::::::::::::::
::::::::::::::::::::::::::::::::::::............::::::::.............................:::::::::::::::
:::::::::::::::::::::::::::..:...:...::::.....:..:::::::::...................:::::......::::::::::::
:::::::::::::::::::::::::..::...::..::::::::...::::::::::.......::..........:::::::::...::::-:::::::
::::::::::::::::::::::....:::..::..:::::::::::::...::.:.........::::...... .:::::::::::...::::::::::
:::::---::----:::::......::::..::..:::::::::::::....:..............:::......::::::::::---:.:::::::::
::::----------:...::....::::..::::::::::::::::::.....::............:::...::::--:---=------....::::::
::::::------::..::-:...:::::..:::::::::::::::.::......::.::...::.::::::....::::.:--=-==--:..:..:::::
:::::::::::.....:::..:---:::..:::::::::::::::.::..:....:..:...:::::..::....:.....:::---:::...:.:::::
:::::::..............::-::::.::::::::::::::.......::..............   .::..:..:. .....::::::....:::::
:::........::..............:..::::::::::::......::::........          .:..:..:..........:::.........
:::::...::::::............:::..:..:::::::..:...:::::...                ..:................:::-:.....
::::..::::::::::::.......::::.....:::::::.:..:::..                       ..................:::::...:
:...:::::::::::.:::....:::::......::::::....                    ..        .::.................:::...
..:::::::::::----::..:.:::..............                       ...         ....:.........:...:::::..
::::::::-------==:::::.:::.......                              ..      ........:....................
::::::.:---------:::::::....                      .              .......::.....:....................
::......::::-::::::.....                                    ..:..:::....::.....:....:::.....::......
...::::::::....::..                      .            ...::.:::.::.....:::..:... .:..:::........::::
:::::::::......:::.       ..          .  ..      ...::::::::::..:......:::::......:..:::..:::::::...
:..........::..:::....    ..                ...:::::.......::...:::....:...  ......:.....:::::::::::
::........::..::...::.     ..          ....:::::...      .....::::..::.. ..   ...........:..........
::.....:::::.:::..:::.            ....::::::::::...   .......::::..:::.  ....   .......:::::::::::..
....::::::----::.::::...      .....:::::::::::::.............::::::::.    ..:.........::::::::::::::
:::::::::::::...::::...............:::::::::::::::........::::::::::...  ....::::.............::::::
:::::::... .....:........    .......::::::::::::::::...:::::::::::...::.  .....::::::::.............
.....:......::.::..:...   .. ........::::::::::::::::.:::::::::....:::::.  .................::::::::
::::.....:::::.....:.........::.............:::::::::::::::::....::::::::...................::::::::
:.....::::::::...............:::.....::...   ....    ..  ......::::::::::::.....::.........:::::::::
...::::::::::::..............:......:::....:::::::..     ..:::..:::::::::::::::.........::::::::::::
.:::::........::...::..............::...::::::::::::::.....::::.....:::::....:::::::::::::::::::::::
:::....::::::::..................:.....:::::::::::::::::::::::::::::::.....::::::::::::.............
.....:::::..........::................::::::::::::::::::::::::::::::::::::::::::::::.....  .. ...
. .:::::.....:::::::........::...... .::::::::::::::::::::::::::::::::::::::::::::...  .....  ....
...:::.....::::::::...::::::::...... .::::::::::::::::::::::::::::::::::::::::::..............     .
:.:::....::::::::.:::::::::::....:::..::::::::::::::::::::::.::::::::::::::::::.::::::::::.......  .
:.:::.. :::::::.:::::::::::....::::::..:::::::::::::::::::::..:::::---::----::.::.::::::::::::. ..

saved to: pfp.txt
```

==> ascii_img_stuff-0.1.4.tar.gz: ascii_img_stuff-0.1.4/README.md <==
# about 
ascii .txt image rendering with python
*i use this to make ascii drawings on my page lol

## installation
**WORKS IN WSL2 and DEBIAN/UBUNTU \*NIX**
#### using pip
```bash
pip install ascii_img_stuff==0.1.3

# the python binary is installed to $HOME/.local/bin/ascii
# run the ascii command and fill in the details it asks for
ascii
```
#### using git
```bash

git clone "https://github.com/hashirkz/ascii_stuff"
cd ascii_stuff
./setup.sh

# installs python program to ~/.local/bin/ascii
ascii
```

### example
```
sleepyzzz:/mnt/c/users/hashi/documents/ascii_stuff$ ascii
path to img: ./imgs/pfp.jpg
height for .txt file: 40
invert y/n: n
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::.::::::::::::::::::::::::::::
:::::::::::::::::::::::::::::::::::::-:::::::::::::::::::::::::::::::..:::::::::::::::::::::::::::::
::::::::::::::::::::::::::::::::::::--:::..................:.::::::::..::........:::::::::::::::::::
::::::::::::::::::::::::::::::::::::............::::::::.............................:::::::::::::::
:::::::::::::::::::::::::::..:...:...::::.....:..:::::::::...................:::::......::::::::::::
:::::::::::::::::::::::::..::...::..::::::::...::::::::::.......::..........:::::::::...::::-:::::::
::::::::::::::::::::::....:::..::..:::::::::::::...::.:.........::::...... .:::::::::::...::::::::::
:::::---::----:::::......::::..::..:::::::::::::....:..............:::......::::::::::---:.:::::::::
::::----------:...::....::::..::::::::::::::::::.....::............:::...::::--:---=------....::::::
::::::------::..::-:...:::::..:::::::::::::::.::......::.::...::.::::::....::::.:--=-==--:..:..:::::
:::::::::::.....:::..:---:::..:::::::::::::::.::..:....:..:...:::::..::....:.....:::---:::...:.:::::
:::::::..............::-::::.::::::::::::::.......::..............   .::..:..:. .....::::::....:::::
:::........::..............:..::::::::::::......::::........          .:..:..:..........:::.........
:::::...::::::............:::..:..:::::::..:...:::::...                ..:................:::-:.....
::::..::::::::::::.......::::.....:::::::.:..:::..                       ..................:::::...:
:...:::::::::::.:::....:::::......::::::....                    ..        .::.................:::...
..:::::::::::----::..:.:::..............                       ...         ....:.........:...:::::..
::::::::-------==:::::.:::.......                              ..      ........:....................
::::::.:---------:::::::....                      .              .......::.....:....................
::......::::-::::::.....                                    ..:..:::....::.....:....:::.....::......
...::::::::....::..                      .            ...::.:::.::.....:::..:... .:..:::........::::
:::::::::......:::.       ..          .  ..      ...::::::::::..:......:::::......:..:::..:::::::...
:..........::..:::....    ..                ...:::::.......::...:::....:...  ......:.....:::::::::::
::........::..::...::.     ..          ....:::::...      .....::::..::.. ..   ...........:..........
::.....:::::.:::..:::.            ....::::::::::...   .......::::..:::.  ....   .......:::::::::::..
....::::::----::.::::...      .....:::::::::::::.............::::::::.    ..:.........::::::::::::::
:::::::::::::...::::...............:::::::::::::::........::::::::::...  ....::::.............::::::
:::::::... .....:........    .......::::::::::::::::...:::::::::::...::.  .....::::::::.............
.....:......::.::..:...   .. ........::::::::::::::::.:::::::::....:::::.  .................::::::::
::::.....:::::.....:.........::.............:::::::::::::::::....::::::::...................::::::::
:.....::::::::...............:::.....::...   ....    ..  ......::::::::::::.....::.........:::::::::
...::::::::::::..............:......:::....:::::::..     ..:::..:::::::::::::::.........::::::::::::
.:::::........::...::..............::...::::::::::::::.....::::.....:::::....:::::::::::::::::::::::
:::....::::::::..................:.....:::::::::::::::::::::::::::::::.....::::::::::::.............
.....:::::..........::................::::::::::::::::::::::::::::::::::::::::::::::.....  .. ...
. .:::::.....:::::::........::...... .::::::::::::::::::::::::::::::::::::::::::::...  .....  ....
...:::.....::::::::...::::::::...... .::::::::::::::::::::::::::::::::::::::::::..............     .
:.:::....::::::::.:::::::::::....:::..::::::::::::::::::::::.::::::::::::::::::.::::::::::.......  .
:.:::.. :::::::.:::::::::::....::::::..:::::::::::::::::::::..:::::---::----::.::.::::::::::::. ..

saved to: pfp.txt
```
